==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Input.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { InputBase } from "./InputBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
/**
 * @hidden
 */
var Input = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Input, _super);
    function Input() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = null;
        return _this;
    }
    Input.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.q("change", function (a) { return _this.change(_this, ComponentValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.t("change");
        }
    };
    Object.defineProperty(Input.prototype, "am", {
        get: function () {
            var ret_ = this.f.m("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ab", {
        get: function () {
            var ret_ = this.f.m("type");
            ret_ = enumGetBox(InputType_$type, EnumUtil.getEnumValue(InputType_$type, this.f.f(InputType_$type, ret_)));
            return EnumUtil.getEnumValue(InputType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "aa", {
        get: function () {
            var ret_ = this.f.m("inputmode");
            ret_ = enumGetBox(InputInputmode_$type, EnumUtil.getEnumValue(InputInputmode_$type, this.f.f(InputInputmode_$type, ret_)));
            return EnumUtil.getEnumValue(InputInputmode_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputInputmode_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("inputmode", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "al", {
        get: function () {
            var ret_ = this.f.m("pattern");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("pattern", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ad", {
        get: function () {
            var ret_ = this.f.m("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "af", {
        get: function () {
            var ret_ = this.f.m("minlength");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("minlength", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ae", {
        get: function () {
            var ret_ = this.f.m("maxlength");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("maxlength", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ak", {
        get: function () {
            var ret_ = this.f.m("min");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("min", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "aj", {
        get: function () {
            var ret_ = this.f.m("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ag", {
        get: function () {
            var ret_ = this.f.m("step");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("step", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ac", {
        get: function () {
            var ret_ = this.f.m("autofocus");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("autofocus", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ai", {
        get: function () {
            var ret_ = this.f.m("autocomplete");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("autocomplete", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ah", {
        get: function () {
            var ret_ = this.f.m("tabIndex");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("tabIndex", value_);
        },
        enumerable: false,
        configurable: true
    });
    Input.prototype.ap = function () {
        this.nativeElement.reportValidity();
    };
    Input.prototype.ao = function () {
        this.nativeElement.checkValidity();
    };
    Input.prototype.ar = function (a) {
        this.nativeElement.setCustomValidity(this.f.h(a));
    };
    Input.prototype.aq = function () {
        this.nativeElement.select();
    };
    Input.prototype.at = function (a) {
        this.nativeElement.stepUp(this.f.h(a));
    };
    Input.prototype.as = function (a) {
        this.nativeElement.stepDown(this.f.h(a));
    };
    Input.$t = markType(Input, 'Input', InputBase.$);
    return Input;
}(InputBase));
export { Input };

==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/Input.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { InputBase } from "./InputBase";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
/**
 * @hidden
 */
var Input = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Input, _super);
    function Input() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = null;
        return _this;
    }
    Input.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.r("change", function (a) { return _this.change(_this, ComponentValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("change");
        }
    };
    Object.defineProperty(Input.prototype, "an", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ae", {
        get: function () {
            var ret_ = this.f.n("type");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(InputType_$type, EnumUtil.getEnumValue(InputType_$type, this.f.f(InputType_$type, ret_)));
            return EnumUtil.getEnumValue(InputType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputType_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ad", {
        get: function () {
            var ret_ = this.f.n("inputmode");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(InputInputmode_$type, EnumUtil.getEnumValue(InputInputmode_$type, this.f.f(InputInputmode_$type, ret_)));
            return EnumUtil.getEnumValue(InputInputmode_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputInputmode_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("inputmode", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "am", {
        get: function () {
            var ret_ = this.f.n("pattern");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("pattern", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ah", {
        get: function () {
            var ret_ = this.f.n("minLength");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("minLength", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ag", {
        get: function () {
            var ret_ = this.f.n("maxLength");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("maxLength", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "al", {
        get: function () {
            var ret_ = this.f.n("min");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("min", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ak", {
        get: function () {
            var ret_ = this.f.n("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ai", {
        get: function () {
            var ret_ = this.f.n("step");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("step", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "af", {
        get: function () {
            var ret_ = this.f.n("autofocus");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("autofocus", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "aj", {
        get: function () {
            var ret_ = this.f.n("autocomplete");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("autocomplete", value_);
        },
        enumerable: false,
        configurable: true
    });
    Input.prototype.ap = function () {
        this.nativeElement.select();
    };
    Input.prototype.ar = function (a) {
        if (a === void 0) {
            a = -1;
        }
        this.nativeElement.stepUp(this.f.i(a));
    };
    Input.prototype.aq = function (a) {
        if (a === void 0) {
            a = -1;
        }
        this.nativeElement.stepDown(this.f.i(a));
    };
    Input.$t = markType(Input, 'Input', InputBase.$);
    return Input;
}(InputBase));
export { Input };
